pub struct MetricNumber(pub usize);Expand description
Implements Display to print the number with metric prefixes using fixed 4 space plus the metric prefix (you have to print a unit thereafter)
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for MetricNumber
impl Clone for MetricNumber
Sourcefn clone(&self) -> MetricNumber
fn clone(&self) -> MetricNumber
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetricNumber
impl Debug for MetricNumber
Sourceimpl Display for MetricNumber
impl Display for MetricNumber
Sourceimpl Ord for MetricNumber
impl Ord for MetricNumber
Sourcefn cmp(&self, other: &MetricNumber) -> Ordering
fn cmp(&self, other: &MetricNumber) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetricNumber
impl PartialEq for MetricNumber
Sourcefn eq(&self, other: &MetricNumber) -> bool
fn eq(&self, other: &MetricNumber) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetricNumber
impl PartialOrd for MetricNumber
impl Copy for MetricNumber
impl Eq for MetricNumber
impl StructuralPartialEq for MetricNumber